searchData={"items":[{"type":"module","title":"SAXMap","doc":"XML to Map conversion.\n\nSAXMap uses a SAX parser (built on top of [Saxy](https://hex.pm/packages/saxy)) to transfer an XML string or file stream into a `Map` containing a collection\nof pairs where the key is the element name and the value is its content, and it is a optional to process element attribute into the result.","ref":"SAXMap.html"},{"type":"function","title":"SAXMap.from_stream/2","doc":"Use `Saxy.parse_stream/4` with a custom SAX parse handler to extract a `Map` containing a collection of pairs where the key is the element name\nand the value is its content, there can optionally append the key-value pair from the attribute of element.","ref":"SAXMap.html#from_stream/2"},{"type":"function","title":"Options - SAXMap.from_stream/2","doc":"Please see `from_string/2`","ref":"SAXMap.html#from_stream/2-options"},{"type":"function","title":"SAXMap.from_string/2","doc":"Use `Saxy.parse_string/4` with a custom SAX parse handler to extract a `Map` containing a collection of pairs where the key is the element name\nand the value is its content, there can optionally append the key-value pair from the attribute of element.","ref":"SAXMap.html#from_string/2"},{"type":"function","title":"Example - SAXMap.from_string/2","doc":"Here is an example:\n\n    iex> xml = \"\"\"\n    ...> <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n    ...>  \n    ...>    Hello \n    ...>    \n    ...>      item1 \n    ...>      item2 \n    ...>    \n    ...>  \n    ...> \"\"\"\n    iex> SAXMap.from_string(xml)\n    {:ok,\n     %{\n       \"thread\" => %{\"items\" => %{\"item\" => [\"item1\", \"item2\"]}, \"title\" => \"Hello\"}\n     }}","ref":"SAXMap.html#from_string/2-example"},{"type":"function","title":"Options - SAXMap.from_string/2","doc":"* `:ignore_attribute`, whether to ignore the attributes of elements in the final map, by default is `true` so\n  there will not see any attributes in the result; when set this option as `false`, it equals `{false, \"\"}`,\n  in this case, there with append the attributes of all elements by the processing order, and put the attributes\n  key-value pair into the peer child elements, and automatically naming child elements with \"content\",\n  we can also set this option as `{false, \"@\"}` or `{false, \"-\"}`, any proper naming prefix you perfer should be fine to process.\n\n  ```\n  xml = \"\"\"\n     \n       Hello \n       \n         item1 \n         item2 \n         item3 \n       \n     \n  \"\"\"\n\n  # set ignore_attribute: false\n  SAXMap.from_string(xml, ignore_attribute: false)\n\n  {:ok,\n    %{\n      \"thread\" => %{\n        \"content\" => %{\n          \"items\" => %{\n            \"content\" => %{\n              \"item\" => [\n                %{\"content\" => \"item1\", \"font\" => \"12\"},\n                %{\"content\" => \"item2\", \"font\" => \"12\"},\n                %{\"content\" => \"item3\", \"font\" => \"12\"}\n              ]\n            },\n            \"size\" => \"3\"\n          },\n          \"title\" => %{\"color\" => \"red\", \"content\" => \"Hello\", \"font\" => \"16\"}\n        },\n        \"version\" => \"1\"\n      }\n    }}\n\n  # set ignore_attribute: {false, \"@\"}\n  SAXMap.from_string(xml, ignore_attribute: {false, \"@\"})\n\n  {:ok,\n    %{\n      \"thread\" => %{\n        \"@version\" => \"1\",\n        \"content\" => %{\n          \"items\" => %{\n            \"@size\" => \"3\",\n            \"content\" => %{\n              \"item\" => [\n                %{\"@font\" => \"12\", \"content\" => \"item1\"},\n                %{\"@font\" => \"12\", \"content\" => \"item2\"},\n                %{\"@font\" => \"12\", \"content\" => \"item3\"}\n              ]\n            }\n          },\n          \"title\" => %{\"@color\" => \"red\", \"@font\" => \"16\", \"content\" => \"Hello\"}\n        }\n      }\n    }}\n  ```\n\nPlease notice that the comments of XML are ignored.","ref":"SAXMap.html#from_string/2-options"},{"type":"extras","title":"SAXMap","doc":"# SAXMap\n\n[![hex.pm version](https://img.shields.io/hexpm/v/sax_map.svg?v=1)](https://hex.pm/packages/sax_map)\n\nConverts an XML String or an XML file stream to a Map.\n\nBenefit from [Saxy](https://hex.pm/packages/saxy)'s SAX mode, this library has a good conversion efficiency.","ref":"readme.html"},{"type":"extras","title":"Installation - SAXMap","doc":"```elixir\ndef deps do\n  [\n    {:sax_map, \"~> 1.4\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Example - SAXMap","doc":"```elixir\n\niex(1)> xml = \"\"\"\n...(1)> <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n...(1)>  \n...(1)>    Hello \n...(1)>    \n...(1)>      item1 \n...(1)>      item2 \n...(1)>    \n...(1)>  \n...(1)> \"\"\"\niex(2)> SAXMap.from_string(xml)\n{:ok,\n %{\n   \"thread\" => %{\"items\" => %{\"item\" => [\"item1\", \"item2\"]}, \"title\" => \"Hello\"}\n }}\n```\n\nBy default `SAXMap.from_string` will ignore all attributes of elements in the result, if you want to merge the attributes as the child elements, please use `ignore_attribute` option to achieve this:\n\n```\nxml = \"\"\"\n   \n     Hello \n     \n       item1 \n       item2 \n       item3 \n     \n   \n\"\"\"\n\nSAXMap.from_string(xml, ignore_attribute: false)\n\n{:ok,\n  %{\n    \"thread\" => %{\n      \"content\" => %{\n        \"items\" => %{\n          \"content\" => %{\n            \"item\" => [\n              %{\"content\" => \"item1\", \"font\" => \"12\"},\n              %{\"content\" => \"item2\", \"font\" => \"12\"},\n              %{\"content\" => \"item3\", \"font\" => \"12\"}\n            ]\n          },\n          \"size\" => \"3\"\n        },\n        \"title\" => %{\"color\" => \"red\", \"content\" => \"Hello\", \"font\" => \"16\"}\n      },\n      \"version\" => \"1\"\n    }\n  }}\n\nSAXMap.from_string(xml, ignore_attribute: {false, \"@\"})\n{:ok,\n  %{\n    \"thread\" => %{\n      \"@version\" => \"1\",\n      \"content\" => %{\n        \"items\" => %{\n          \"@size\" => \"3\",\n          \"content\" => %{\n            \"item\" => [\n              %{\"@font\" => \"12\", \"content\" => \"item1\"},\n              %{\"@font\" => \"12\", \"content\" => \"item2\"},\n              %{\"@font\" => \"12\", \"content\" => \"item3\"}\n            ]\n          }\n        },\n        \"title\" => %{\"@color\" => \"red\", \"@font\" => \"16\", \"content\" => \"Hello\"}\n      }\n    }\n  }}\n```\n\n**Please note**: The `ignore_attribute: false` equals `ignore_attribute: {false, \"\"}`, in this case, the child elements will be automatically naming with `\"content\"` as the key of the key-value pair to distinct this key-value pair is from XML text content or attribute. Currently, the `\"content\"` naming is a reserved keyword, please be careful to distinguish it from the XML node name when transfer an XML to a Map be with XML attributes.","ref":"readme.html#example"},{"type":"extras","title":"Benchmark - SAXMap","doc":"Only for your reference, all credit goes to [Saxy](https://hex.pm/packages/saxy), the details of benchmark can be found in the `bench` directory of the repository.\n\nRun:\n\n```bash\nmix run xml_to_map.exs\n```\n\nOutput:\n\n```bash\nOperating System: macOS\nCPU Information: Intel(R) Core(TM) i9-9880H CPU @ 2.30GHz\nNumber of Available Cores: 16\nAvailable memory: 32 GB\nElixir 1.12.2\nErlang 24.0.4\n\nBenchmark suite executing with the following configuration:\nwarmup: 2 s\ntime: 10 s\nmemory time: 2 s\nparallel: 1\ninputs: none specified\nEstimated total run time: 42 s\n\nBenchmarking SAXMap.from_string ignore attribute...\nBenchmarking SAXMap.from_string with attribute...\nBenchmarking XmlToMap.naive_map...\n\nName                                          ips        average  deviation         median         99th %\nSAXMap.from_string ignore attribute      105.03 K        9.52 μs   ±129.42%           9 μs          33 μs\nSAXMap.from_string with attribute         96.74 K       10.34 μs   ±110.08%           9 μs          35 μs\nXmlToMap.naive_map                        26.31 K       38.01 μs    ±46.21%          33 μs         105 μs\n\nComparison:\nSAXMap.from_string ignore attribute      105.03 K\nSAXMap.from_string with attribute         96.74 K - 1.09x slower +0.82 μs\nXmlToMap.naive_map                        26.31 K - 3.99x slower +28.49 μs\n\nMemory usage statistics:\n\nName                                   Memory usage\nSAXMap.from_string ignore attribute        14.61 KB\nSAXMap.from_string with attribute          16.69 KB - 1.14x memory usage +2.08 KB\nXmlToMap.naive_map                         40.90 KB - 2.80x memory usage +26.29 KB\n\n**All measurements for memory usage were the same**\n```","ref":"readme.html#benchmark"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.0"}}